@@ -31,17 +31,17 @@ Q_OBJECT
 		bool isAsker() const;
 		
 	protected:
-		void nextQuestionHook(const QString &division);
-		void mousePressEvent(QMouseEvent *e);
-		QString getQuestionHook() const;
-		void showEvent(QShowEvent *e);
-		division::askMode askMode() const { return division::eClick; }
+		void nextQuestionHook(const QString &division) override;
+		void mousePressEvent(QMouseEvent *e) override;
+		QString getQuestionHook() const override;
+		void showEvent(QShowEvent *e) override;
+		division::askMode askMode() const override { return division::eClick; }
 
 	public slots:
-		void setMovement(bool b);
-		void setZoom(bool b);
-		void setOriginalZoom();
-		void setAutomaticZoom(bool b);
+		void setMovement(bool b) override;
+		void setZoom(bool b) override;
+		void setOriginalZoom() override;
+		void setAutomaticZoom(bool b) override;
 	
 	private slots:
 		void handleMapClick(QRgb c, const QPoint &p);
